@@ -1,5 +1,10 @@
 dm.ddf <-
 function(xdata,ydata,rts,g,w=NULL,se=0,sg="ssm",date=NULL){
+
+  # Initial checks
+  if(is.na(match(rts,c("crs","vrs","irs","drs")))){stop('rts must be "crs", "vrs", "irs", or "drs".')}
+  if(is.na(match(se,c(0,1)))){stop('se must be either 0 or 1.')}
+  if(is.na(match(sg,c("ssm","max","min")))){stop('sg must be "ssm", "max", or "min".')}
   
   # Load library
   # library(lpSolveAPI)
